/*
 * (C) Copyright IBM Corp. 1997-1998  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.parser;

import org.w3c.dom.*;

/**
 * The DocumentContext class implements the DocumentContent interface as defined by the Document Object Model (DOM).
 * <p>The DocumentContext object represents information that is not strictly related to a
 * document's content; rather, it provides the information about where the document came
 * from, and any additional meta-data about the document.
 * <p>The DocumentContext is expected to evolved greatly with the level two DOM specification.
 *
 * @version 1.1
 * @author TAMURA Kent &lt;kent@trl.ibm.co.jp&gt;
 * @see com.ibm.xml.parser.Parent
 */
public class TXDocumentContext implements DocumentContext {

                Document    document    =   null;

    /**
     * Constructor.
     */
    public TXDocumentContext() {
    }

    /**
     * Returns the root Node of this document. Any iteration, enumeration, or other
     * traversal of the entire document's content should begin with this Node.
     * @return          Root Node of this Document.
     * @see #setDocument
     */
    public Document getDocument() {
        return this.document;
    }

    /**
     * Sets root Node of this document. Any iteration, enumeration, or other
     * traversal of the entire document's content should begin with this Node.
     * @param   document    Root Node of this Document.
     * @see #getDocument
     */
    public void setDocument(Document document) {
        this.document = document;
    }
}
